@@ -7,8 +7,9 @@ echo "<?xml version='1.0' encoding='UTF-8'?>
     </service>"
 if [ -f /proc/device-tree/model ]
 then
-    VAR=$(cat /proc/device-tree/model)
+    VAR=$(strings /proc/device-tree/model)
     echo "<env id='model'>$VAR</env>"
+    echo "<model>$VAR</model>"
 fi
 for env in $(env | grep CFG);
 do
