@@ -4,7 +4,7 @@ alias showlog='tac /var/log/user.log | grep -B 10000 -m 1 "Isu: \[PINFO\]   1 ."
 alias is_rescue='[ -f /proc/device-tree/board/rescue-mode ] && echo $(cat /proc/device-tree/board/rescue-mode) || echo "no"'
 
 
-source /etc/init.d/otu_functions
+source /usr/lib/otu_functions
 
 IS_OTU_MODE="NO"
 is_cotu_hw
