@@ -34,10 +34,12 @@ class SMTOtuMode
     const OEM       = "OEM";
     const ROTAU     = "ROTAU";
     const RESCUE    = "RESCUE";
-    
+    const UFOM      = "UFOM";
+
     const DEFAULT_OTU_MODE = self::SMART_OTU;
     const SMART_OTU_LOGO = "SmartOtu158x38.png";
     const SMART_OEM_LOGO = "SmartOem164x38.png";
+    const UFOM_LOGO      = "SmartOtuFM180x38.png";
     const OEM_LOGO       = "Oem73x38.png";
     const ROTAU_LOGO     = "Rotau111x38.png";
     const ONMS_LOGO      = "OtuOnms.png";
@@ -53,7 +55,8 @@ class SMTOtuMode
     const ONMS_DISPLAY      = "OTU ONMS";
     const OEM_DISPLAY       = "OEM";
     const ROTAU_DISPLAY     = "ROTAU";
-    const RESCUE_DISPLAY     = "OTU RESCUE";
+    const RESCUE_DISPLAY    = "OTU RESCUE";
+    const UFOM_DISPLAY      = "SmartOTU Fast Monitoring";
     
     
     /**
@@ -64,7 +67,7 @@ class SMTOtuMode
      */
     public static function getSupportedModes()
     {
-        return array(self::SMART_OTU,self::SMART_OEM, self::ONMSI, self::ONMS, self::OEM, self::ROTAU, self::RESCUE );
+        return array(self::SMART_OTU,self::SMART_OEM, self::ONMSI, self::ONMS, self::OEM, self::ROTAU, self::RESCUE, self::UFOM );
     }    
     
     /**
@@ -75,6 +78,15 @@ class SMTOtuMode
     {
         return ( strcasecmp( self::getOtuMode() , self::SMART_OTU ) == 0 );
     }
+    
+    /**
+     * Whether the OTU mode is SmartOTU or UFOM
+     * @return boolean Whether the OTU mode is SmartOTU
+     */
+    public static function isSmartOtuFamily()
+    {
+    	return self::isSmartOtu() || self::isUFOM();
+    }
 
     /**
      * Whether the OTU mode is SmartOEM
@@ -130,6 +142,15 @@ class SMTOtuMode
     	return ( strcasecmp( self::getOtuMode() , self::RESCUE ) == 0 );
     }
     
+    /**
+     * Whether the OTU mode is UFOM
+     * @return boolean Whether the OTU mode is UFOM
+     */
+    public static function isUFOM()
+    {
+    	return ( strcasecmp( self::getOtuMode() , self::UFOM) == 0 );
+    }
+    
     /**
      * Whether the string value is an existing OTU mode
      *
@@ -144,7 +165,8 @@ class SMTOtuMode
 	         strcasecmp( $mode , self::ONMS ) == 0  ||
 	         strcasecmp( $mode , self::OEM ) == 0  ||
 	         strcasecmp( $mode , self::ROTAU ) == 0 || 
-    	     strcasecmp( $mode , self::RESCUE ) == 0
+    	     strcasecmp( $mode , self::RESCUE ) == 0 ||
+    	     strcasecmp( $mode , self::UFOM ) == 0
     	   )
     	{
     		return true;
@@ -187,6 +209,10 @@ class SMTOtuMode
         {
         	return self::RESCUE_LOGO;
         }
+        else if ( self::isUFOM() )
+        {
+        	return self::UFOM_LOGO;
+        }
     }
     
     /**
@@ -220,9 +246,9 @@ class SMTOtuMode
     	{
     		return self::ROTAU_DISPLAY;
     	}
-    	else if ( self::isRESCUE() )
+    	else if ( self::isUFOM() )
     	{
-    		return self::RESCUE_DISPLAY;
+    		return self::UFOM_DISPLAY;
     	}    	
     }
     
