@@ -170,7 +170,15 @@ class SMTOtuApi
     static function getOtuDate()
     {
     	return self::CMD_otu_dateTime;    
-    }    
+    }
+    const CMD_get_otu_dateTime_tz = 'OTU:SYSTEM:TZDATE?';
+    /**
+     * @return string //mm
+     */
+    static function getOtuDateTZ()
+    {
+        return self::CMD_get_otu_dateTime_tz;
+    }
     /**
      * YYYY // MM // DD // HH24 // mm // SS
      */    
@@ -188,6 +196,22 @@ class SMTOtuApi
     	return sprintf( self::CMD_otu_dateTime, $YYYY, $MM, $DD, $HH24, $mm, $SS );
     }    
     
+    /**
+     * YYYY // MM // DD // HH24 // mm // SS
+     */
+    const CMD_set_otu_dateTime_tz = 'OTU:SYSTEM:TZDATE %d,%d,%d,%d,%d,%d,%d';
+    /**
+     * @param int $YYYY
+     * @param int $MM
+     * @param int $DD
+     * @param int $HH24
+     * @param int $mm
+     * @param int $SS
+     */
+    static function setOtuDateTz( $YYYY, $MM, $DD, $HH24, $mm, $SS, $TZ )
+    {
+        return sprintf( self::CMD_set_otu_dateTime_tz, $YYYY, $MM, $DD, $HH24, $mm, $SS, $TZ );
+    }  
     //TYPE d'OTU (COTU,8KV2,EOTDRV2,MTS8KV2)
     const CMD_OTU_TYPE = 'OTU:HWABILITY? NAME';
     /**
@@ -956,6 +980,9 @@ class SMTOtuApi
     const CMD_get_osu_ports = 'OTU:SWITCH:OSUS:PORT? %s';    //OSU1/OSU2/...OSU31
     const CMD_get_bigtopo = 'OTU:SWITCH:CONF:BIGT? %d';    //0/1... // Macroswitchid
     const CMD_set_bigtopo = 'OTU:SWITCH:CONF:BIGT %d, %s';    //0/1... forMacroswitchid, TRUE/FALSE
+    const CMD_get_Nb_Port_Distributeur = 'OTU:SWITCH:CONFIG:DIST?';
+    const CMD_set_Nb_Port_Distributeur = 'OTU:SWITCH:CONFIG:DIST %d';
+    const CMD_Has_Fixed_Port_Distributeur = 'OTU:SWITCH:CONFIG:FIXDist?';
     const CMD_show_osx = 'OTU:SWITCH:OSUJ:SHOW %d ';    //0/1... osx address
     const CMD_power_on_off_osx = 'OTU:SWITCH:OSXJ:CONN %s ';//DISABLED/ENABLED
     const CMD_get_power_on_off_osx = 'OTU:SWITCH:OSXJ:CONN?';//DISABLED/ENABLED
@@ -970,6 +997,7 @@ class SMTOtuApi
     const CMD_switch_detect_calib_SerialNum = 'OTU:SWITCH:CONFIG:DETECT:SER? %d,%s'; //0,INT/OSU1/OSU2 ... ... OSU31//Detection from calibration
     const CMD_get_switch_ports = 'OTU:SWITCH:CONF:PORT? %d';    //0/1/2/3/...31
     const CMD_get_switch_jdsu_idn = 'OTU:SWITCH:OSXJdsu:IDN? %d';
+    const CMD_get_switch_jdsu_idn_scan = 'OTU:SWITCH:OSXJdsu:SIDN? %d';    
     const CMD_switch_detect_Serial_Number_List = 'OTU:SWITCH:OSUS:DETSERial?';
     const CMD_switch_config_Serial_Number_List = 'OTU:SWITCH:OSUS:CONFSERial?';
     const CMD_switch_osx_detect_Serial_Number_List = 'OTU:SWITCH:OSXJdsu:DETSERial?';
@@ -979,7 +1007,9 @@ class SMTOtuApi
     const CMD_get_switch_molex_idn = 'OTU:SWITCH:MOLEX:IDN? %d';
     const CMD_get_switch_molex_available = 'OTU:SWITCH:MOLEX:AVAIlable?'; //TRUE/FALSE
     const CMD_get_switch_config_type = 'OTU:SWITCH:CONFIG:TYPE? %d'; //OSX_JDSU, MOLEX
-    
+    const CMD_Has_Internal_Switch_License = 'OTU:SWITCH:LIC:INTValid?';
+    const CMD_Get_Internal_Switch_Total_Ports = 'OTU:SWITCH:CONFIG:INTOutputs?';
+        
     //OTAU NEW FUNCTIONS to handle big configurations of ROTAUs
     const CMD_compare_switches = 'OTU:SWITCH:COMPAR:MACRO? %d';//0/1... for Macroswitchid, returns SAME,DIFF,MISSCONF,MISSDET
     const CMD_compare_switches_result = 'OTU:SWITCH:COMPAR:RESULT? %d';//0/1... for Macroswitchid, returns SAME,DIFF,MISSCONF,MISSDET
@@ -2213,6 +2243,18 @@ class SMTOtuApi
     	return sprintf(self::CMD_otu_is_option_status, $option);
     }
     
+    const CMD_otu_get_PAYG_internal_switch_lic_count = "OTU:SWITCH:LIC:INTCount?";
+    
+    /**
+     * OTU COMMAND
+     *
+     * @return integer number of PYG license count for internal switch
+     */
+    static function getOtu_PAYG_Internal_Switch_Lic_Count()
+    {
+        return self::CMD_otu_get_PAYG_internal_switch_lic_count;
+    }
+    
     /**
      * OTU COMMAND
      *
@@ -2312,6 +2354,15 @@ class SMTOtuApi
     	return sprintf(self::CMD_otu_is_option_status, SMTLicenseList::OTU_OPTION_REST_API);
     }
     
+    /**
+     * OTU COMMAND
+     *
+     * @return string //IMPOSSIBLE POSSIBLE AVAILABLE EXPIRED
+     */
+    static function isOtu_Vpn_Option()
+    {
+        return sprintf(self::CMD_otu_is_option_status, SMTLicenseList::OTU_OPTION_VPN);
+    }
     /**
      * WARNING ISU COMMANDS
      * WARNING ISU COMMANDS
@@ -2328,6 +2379,7 @@ class SMTOtuApi
     const CMD_get_OTU_LICENSE = "ISU:LIC:LIST? \"OTU\"";
     const CMD_get_Sensing_LICENSE = "ISU:LIC:LIST? \"Sensing\"";
     const CMD_get_SAA_LICENSE = "ISU:LIC:LIST? \"Anywhere\"";
+    const CMD_get_OTAU_LICENSE = "ISU:LIC:LIST? \"Otau\"";
     
     /**
      * WARNING ISU COMMAND
@@ -2347,6 +2399,16 @@ class SMTOtuApi
     {
     	return self::CMD_get_Sensing_LICENSE;
     }
+    /**
+     * WARNING ISU COMMAND
+     *
+     * @return string
+     */
+    static function getOtauLicensesFromIsu()
+    {
+        return self::CMD_get_OTAU_LICENSE;
+    }
+    
     /**
      * WARNING ISU COMMAND
      *
@@ -2408,6 +2470,19 @@ class SMTOtuApi
     {
     	return sprintf(self::CMD_isu_license_import, $licenseFileName);
     }
+    
+    const CMD_isu_get_payg_option_value= "isu:lic:payg? \"Otau\",\"%s\"";
+    /**
+     * WARNING ISU COMMAND
+     *
+     * @param $option Option PAYG key
+     *
+     * @return string
+     */
+    static function getOtu_Option_Value($option)
+    {
+        return sprintf(self::CMD_isu_get_payg_option_value, $option);
+    }
         
     //Hard disk
     const CMD_get_harddisk_status = 'OTU:HDISK:STATUS?';
@@ -2434,17 +2509,58 @@ class SMTOtuApi
     }        
     
     const CMD_get_otu_mon_mode= 'OTU:TOPAZ:MON:MODe?';
-    function get_otu_mon_mode()
+    static function get_otu_mon_mode()
     {
     	return self::CMD_get_otu_mon_mode;
     }
     
     const CMD_set_otu_mon_mode= "OTU:TOPAZ:MON:MODe %s";
-    function set_otu_mon_mode($mode)
+    static function set_otu_mon_mode($mode)
     {
     	return sprintf( self::CMD_set_otu_mon_mode, $mode);
     }
     
+    const CMD_create_ufom_archive="OTU:UFOM:ARCH:CSVSOR?";
+    static function create_ufom_archive()
+    {
+        return self::CMD_create_ufom_archive;
+    }
+    
+    ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+    //
+    // API
+    //
+    ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+    const CMD_activate_vpn ='OTU:API:CONF:VPN:ENABLE TRUE';
+    /**
+     * Activate vpn command Command
+     * @return string command
+     */
+    static function getActivateVpnCommand()
+    {
+        return self::CMD_activate_vpn;
+    }
+    
+    const CMD_disable_vpn ='OTU:API:CONF:VPN:ENABLE FALSE';
+    /**
+     * Disable vpn Command
+     * @return string command
+     */
+    static function getDisableVpnCommand()
+    {
+        return self::CMD_disable_vpn;
+    }
+    
+    const CMD_vpn_file ='OTU:API:CONF:VPN:FILE?';
+    /**
+     * Vpn configuration file name Command
+     * @return string command
+     */
+    static function getVpnFileCommand()
+    {
+        return self::CMD_vpn_file;
+    } 
+    
     const CMD_is_ntp_enabled= "OTU:API:CONF:NTP:ENABLE?";
     function getNtpActive()
     {
@@ -2456,12 +2572,6 @@ class SMTOtuApi
     {
     	return self::CMD_get_ntp_sync;
     }
-
-    ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-    //
-    // API
-    //
-    ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
     
     const CMD_Api_get_otu_Main_INFO= 'OTU:API:CONF:SUMary?';
     /**
@@ -2593,7 +2703,6 @@ class SMTOtuApi
     {
     	return self::CMD_Api_HasSmartOTUGuestUser;
     }
-    
 }
 
 
