@@ -923,7 +923,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
     			catch(\Exception $ex)
     			{
     				$linkDto->resetTestId( );
-    				$this->getContext()->getLogger()->traceException( $e );
+    				$this->getContext()->getLogger()->traceException( $ex );
     			}
     		}
     	}
@@ -1093,7 +1093,6 @@ class SMTLinkTestService extends SMTService implements SMTIService
         	
         	//test if a link exists:
         	$linkId = $this->sendReceive( SMTOtuApi::getLinkListPerPortCommand($portid, $portid) );
-        	$testDetailDto = NULL;
         	if ( SMTLinkTest::checkLinkTestId( $linkId, FALSE ) )
         	{
         		//does a test exist?
@@ -1347,7 +1346,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
      *
      * @url GET /test/createAllLinks
      */
-    function testCreateAllLinks()
+    function testCreateAllLinks($request_data)
     {
     	$linkId = -1;
     	$linkHelper = new SMTLinkTest();
