@@ -13,14 +13,13 @@
 // *********************************************************
 namespace app\services\monitoring;
 
-use app\serviceshelper\otdr\SMTOtdrTraceFileUtil;
-
 use app\util\SMTInvalidValueException;
 use app\util\SMTUtil;
 use app\util\SMTRwDto;
 use app\serviceshelper\otdr\SMTOtdrTraceType;
 use app\settings\SMTSmartOtuThresholds;
 use app\serviceshelper\monitoring\SMTPeakShiftMode;
+use app\serviceshelper\monitoring\SMTTestMode;
 
 /**
  * Monitoring test data: otdr trace name, markers, thresholds
@@ -32,7 +31,14 @@ class SMTTestDetailDto extends SMTRwDto
     /**
      * @var number
      */
-    protected $testId;    
+    protected $testId;
+    
+    /**
+     * Test mode: OTDR,HIGHSENS,TAPPING...
+     * @var string
+     */
+    protected $mode = SMTTestMode::HIGHSENS;
+    
     /**
      * OTDR trace name with its extesion but without its path
      * @var string
@@ -81,6 +87,14 @@ class SMTTestDetailDto extends SMTRwDto
      */
     protected $attenuationToBtoDeltaDbDefault = NULL;
     
+    /**
+     * Hysteresis according to alarm attenuation thresholds
+     * @SMTAttributeInfosAnnotation(classname='app\services\monitoring\SMTOtuTestThresholdHysteresisListDto')
+     * @var SMTOtuTestThresholdHysteresisListDto
+     */
+    protected $hysteresisAttenuationThresholdList = NULL;
+    
+    
     // MONITORING PEAK
     // MONITORING PEAK
     // MONITORING PEAK
@@ -97,6 +111,12 @@ class SMTTestDetailDto extends SMTRwDto
      */
     protected $peakMonitoringOptionEnabled = FALSE;
     
+    /**
+     *
+     * @var boolean FALSE by default
+     */
+    protected $tappingMonitoringOptionEnabled = FALSE;
+    
     /**
      * Peak shoft mode: REFERENCE_TRACE, TOLERANCE
      * @var string
@@ -154,6 +174,11 @@ class SMTTestDetailDto extends SMTRwDto
      */
     protected $minAttenuationAlarmThreshold= 0;
     
+    /**
+     * Whether the test has a short Acq
+     * @var boolean
+     */
+    protected $hasShortAcq = FALSE;
                 
     function setTestId( $id )
     {
@@ -164,6 +189,16 @@ class SMTTestDetailDto extends SMTRwDto
     	return $this->testId;
     }
 
+    function setTestMode( $mode)
+    {
+    	$this->mode= $mode;
+    }
+    
+    function getTestMode()
+    {
+    	return $this->mode;
+    }
+    
     /**
      * Set OTDR trace name (with its extension)
      * @param string $otdrReferenceTraceName
@@ -181,9 +216,14 @@ class SMTTestDetailDto extends SMTRwDto
     	return $this->otdrReferenceTraceName;
     }
     
-    function getOtdrTraceNameWithoutExtension()
+    /**
+     * Get OTDR trace name (without extension)
+     * @return string
+     */
+    function getOtdrFileNameWithoutExtension()
     {
-    	return basename( $this->otdrReferenceTraceName, SMTOtdrTraceFileUtil::OTDR_FILE_SOR_EXTENSION );
+    	$otdrTraceName= basename( $this->otdrReferenceTraceName);
+    	return substr($otdrTraceName, 0,strrpos($otdrTraceName,"."));
     }        
     
     function setOtdrTraceType( $otdrTraceType )
@@ -235,7 +275,7 @@ class SMTTestDetailDto extends SMTRwDto
     {
     	return $this->lastMarkerDistanceM;
     }
-
+    
     /**
      * 
      * @param SMTOtuMonitoringTestThresholdDto $firstMarkerThresholdsDb
@@ -343,6 +383,15 @@ class SMTTestDetailDto extends SMTRwDto
     	$this->attenuationToBtoDeltaDbDefault = floatval($attenuationToBtoDeltaDbDefault);
     }
     
+    /**
+     *
+     * @param SMTOtuTestThresholdHysteresisListDto $hysteresisAttenuationThresholdsDbList
+     */
+    function setHysteresisAttenuationThresholdsDbList( $hysteresisAttenuationThresholdsDbList)
+    {
+    	$this->hysteresisAttenuationThresholdList= $hysteresisAttenuationThresholdsDbList;
+    }
+    
     //PEAK MONITORING
     //PEAK MONITORING
     //PEAK MONITORING
@@ -369,6 +418,17 @@ class SMTTestDetailDto extends SMTRwDto
     	return $this->peakMonitoringOptionEnabled;
     } 
     
+    public function setTappingMonitoringOptionEnabled( $tappingMonitoringOptionEnabled)
+    {
+    	$this->tappingMonitoringOptionEnabled= filter_var($tappingMonitoringOptionEnabled, FILTER_VALIDATE_BOOLEAN);
+    }
+    
+    
+    public function getTappingMonitoringOptionEnabled()
+    {
+    	return $this->tappingMonitoringOptionEnabled;
+    } 
+    
     /**
      *
      * @param SMTOtuMonitoringTestThresholdDto $defaultPeakThresholdsDb
@@ -485,6 +545,31 @@ class SMTTestDetailDto extends SMTRwDto
     	return $this->minAttenuationAlarmThreshold;
     }
     
+    /**
+     * HIGHSENS or TAPPING mode
+     * @return boolean isHighsensTest
+     */
+    public function isHighsensTest()
+    {
+    	return SMTTestMode::isHighsensOrTappingMode( $this->mode );
+    }
+    
+    /**
+     * @param boolean $hasShortAcq
+     */
+    public function setShortAcq($hasShortAcq)
+    {
+    	$this->hasShortAcq= $hasShortAcq;
+    }
+    
+    /**
+     * @return boolean hasShortAcq
+     */
+    public function hasShortAcq()
+    {
+    	return $this->hasShortAcq;
+    }
+    
     /**
      * Serialize as Json data the user object.<br>
      *
