@@ -83,7 +83,56 @@ class SMTConfDetSwitchDto extends SMTRwDto
 	 * @var boolean
 	 */
 	protected $moduleCompatibleWithSwitch = TRUE;
+		
+	/**
+	 * Number of ports at the end used for distribution.
+	 */
+	protected $portDistributorNumber = 0;
+	
+	/**
+	 * Number of ports at the end used for distribution.
+	 */
+	protected $fixedPortDistributorNumber = FALSE;
 
+	/**
+	 * Whether Number of ports at the end used for distribution is fixed.
+	 *
+	 * @return boolean Whether Number of ports at the end used for distribution is fixed.
+	 */
+	function hasFixedPortDistributorNumber()
+	{
+	    return $this->fixedPortDistributorNumber;
+	}
+	
+	/**
+	 * Set whether number of ports at the end used for distribution is fixed.
+	 *
+	 * @param int  Number of ports at the end used for distribution.
+	 */
+	function setFixedPortDistributorNumber($fixedPortDistributorNumber)
+	{
+	    $this->fixedPortDistributorNumber = $fixedPortDistributorNumber;
+	}
+	
+	/**
+	 * Number of ports at the end used for distribution.
+	 *
+	 * @return int  Number of ports at the end used for distribution.
+	 */
+	function getPortDistributorNumber()
+	{
+	    return $this->portDistributorNumber;
+	}
+	
+	/**
+	 * Set number of ports at the end used for distribution.
+	 *
+	 * @param int  Number of ports at the end used for distribution.
+	 */
+	function setPortDistributorNumber($portDistributorNumber)
+	{
+	    $this->portDistributorNumber = $portDistributorNumber;
+	}
 	
 	/**
 	 *
