@@ -40,7 +40,6 @@ use app\util\SMTLogger;
 
 use app\admin\SMTOtuMonitoringOptions;
 use app\parser\SMTOtuApi;
-use app\services\security\SMTAccessControl;
 use app\services\SMTIService;
 use app\services\SMTService;
 use app\view\SMTTestRestApiPage;
@@ -376,7 +375,7 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
     	    }
     	    catch ( \Exception $e )
     	    {
-    	    	$this->getContext()->getLogger()->traceException( $ex);
+    	    	$this->getContext()->getLogger()->traceException( $e);
     	    }
     	    
     	    if ( $ntp )
@@ -427,13 +426,21 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
     			
             if ( $dateTimeDto != NULL )
             {
+                $otu = new SMTOtu();
+                $otu->setContext( $this->getContext() );
+                
         		//retrieve current OTU date:
-        		$currentTimeStamp = time();//OTU timestamp with timezone offset (not in UTC)
+//         		$currentTimeStamp = time();//OTU timestamp with timezone offset (not in UTC)
+        		
+        		
+        		$currentTimeStamp = $otu->getOtuTimeStamp();
+        		$currentTimeZone = $otu->getOtuDateTz();
+        		
         		$clientTimeStamp = SMTUtil::convertToInt( $dateTimeDto->getTimestamp() );//Client timestamp with timezone offset (not in UTC)
         		$systemConfiguration = SMTSystemConfigurationDto::fetch( $this->getContext()->getDatabase() );
         		$currentTimezoneName = $systemConfiguration->getTimezoneName();
         		$currentTimeZoneDst = $systemConfiguration->isTimezoneDst();
-        		
+        		        		
         		SMTLogger::getInstance()->trace( "currentTimeStamp: ".$currentTimeStamp);
         		SMTLogger::getInstance()->trace( "currentTimezoneName: ".$currentTimezoneName);
         		SMTLogger::getInstance()->trace( sprintf("currentTimezoneDst: %b", $currentTimeZoneDst) );
@@ -441,8 +448,12 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
         		SMTLogger::getInstance()->trace( "clientTimezoneSec: ".$dateTimeDto->getTimezoneSec() );
         		SMTLogger::getInstance()->trace( "clientTimezoneName: ".$dateTimeDto->getTimezoneName());
         		SMTLogger::getInstance()->trace( sprintf("clientTimezoneDst: %b",$dateTimeDto->isTimezoneDst() ));
-        		
-        		
+        		SMTLogger::getInstance()->trace( "currentTimezone OTU: ".$currentTimeZone * 60);
+        		if ( ($currentTimeZone * 60) != $dateTimeDto->getTimezoneSec() )
+        		{
+        		    SMTLogger::getInstance()->trace( "currentTimezone OTU: TimeZone changed" );
+        		}
+
         		//update OTU date time:
         		// - if it is not already set
         		// - or if timezone are the same and if the drift is > 15mn 
@@ -450,14 +461,14 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
         		if ( !isset( $currentTimezoneName ) || ($currentTimezoneName === NULL) ||
         		     ( (abs( $currentTimeStamp - $clientTimeStamp ) >  SMTSmartOtuSettings::getDateTimeMaxDrift() )
         		       && ( strcasecmp($currentTimezoneName, $dateTimeDto->getTimezoneName() ) == 0 ) 
-        		     ) 
+        		         ) || ( ($currentTimeZone * 60) != $dateTimeDto->getTimezoneSec())
         		   )
         		{
         			try
         			{
         				$ntp = ( strcasecmp($this->sendReceive( SMTOtuApi::getNtpActive() ), 'TRUE' ) == 0 );
         			}
-        			catch ( \Exception $e )
+        			catch ( \Exception $ex )
         			{
         				$this->getContext()->getLogger()->traceException( $ex);
         			}
@@ -465,8 +476,7 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
         			if ( !$ntp )
         			{
 	            		//update OTU date time and SmartOtu timezone
-	            		$otu = new SMTOtu();
-	            		$otu->setContext( $this->getContext() );
+
 	            		$otu->setOtuTimeStamp( $dateTimeDto->getTimestamp(), $dateTimeDto->getTimezoneSec(), $dateTimeDto->getTimezoneName(), $dateTimeDto->isTimezoneDst() );
 	            		//check failed: a new date was applied on OTU
 	            		$result = self::RESULT_KO;
@@ -481,7 +491,9 @@ class SMTSmartOtuSettingsService extends SMTService implements SMTIService
     	}
     	catch ( \Exception $e )
     	{
-    		$this->handleException($e);
+    		//$this->handleException($e);  don't throw exception
+    	    $this->getContext()->getLogger()->traceException( $e );
+    	    $result = self::RESULT_KO;
     	}
     	return $result;
     }    
