@@ -161,7 +161,7 @@ class SMTServer extends SMTServiceHelper
 		//remove spaces in array values
 		$serverArray = SMTUtil::splitStringByComma( $serverString );
 		
-		if ( ($serverArray != NULL)&& is_array($serverArray) && ($serverArray[self::TSC_STATUS_INDEX]!= "") && ($serverArray[self::TSC_STATUS_INDEX]!= SMTOtuApi::RES_OFF) && ($serverArray[self::TSC_STATUS_INDEX]!= SMTOtuApi::RES_UNKNOWN) && ($serverArray[self::MAIN_INDEX] != SMTOtuApi::RES_NONE) && ($serverArray[self::MAIN_INDEX] != SMTOtuApi::RES_UNKNOWN_AF))
+		if ( ($serverArray != NULL)&& is_array($serverArray) && ($serverArray[self::TSC_STATUS_INDEX]!= "") && ($serverArray[self::TSC_STATUS_INDEX]!= SMTOtuApi::RES_OFF) && ($serverArray[self::TSC_STATUS_INDEX]!= SMTOtuApi::RES_UNKNOWN) /*&& ($serverArray[self::MAIN_INDEX] != SMTOtuApi::RES_NONE) && ($serverArray[self::MAIN_INDEX] != SMTOtuApi::RES_UNKNOWN_AF)*/)
 		{
 			$serverDto = new SMTOnmsiServerDto();
 			$serverDto->setIndex($serverIndex);
