@@ -15,13 +15,13 @@ namespace app\serviceshelper\monitoring;
 
 use app\services\setup\SMTOtuCurrentPortDto;
 
+use app\admin\SMTOtuMode;
 use app\admin\SMTOtuType;
 
 use app\serviceshelper\alarm\SMTAlarm;
 
 use app\sharedmemory\SMTMemoryManager;
 
-use app\serviceshelper\system\SMTSystemConfigurationDto;
 use app\serviceshelper\otdr\SMTOtdrTraceFileUtil;
 use app\services\monitoring\SMTTestAcquisitionParametersDto;
 use app\util\SMTLogger;
@@ -40,6 +40,7 @@ use app\serviceshelper\maintenance\SMTLicence;
 use app\serviceshelper\otdr\SMTHighsensOtdrTraceFileUtil;
 use app\services\monitoring\SMTOtuTestThresholdHysteresisListDto;
 use app\parser\SMTOtuSocket;
+use app\serviceshelper\system\SMTOtu;
 
 include_once( "phputf8/ascii.php" );
 
@@ -1094,15 +1095,31 @@ class SMTLinkTest extends SMTServiceHelper
         //don't retrieve last monitoring date, measurement allowed... if the link is not connected to a port
         if ( $portCount === NULL || ( $portCount !== NULL && $linkDto->getPortNumber() <= $portCount ) )
         {
-            if( !isset ($this->timezoneOffset) || $this->timezoneOffset === NULL)
-            {
-                //retrieve time zone offset and store it, to avoid to call it for each link retrieval
-                $dto = SMTSystemConfigurationDto::fetch( $this->getContext()->getDatabase() );
-                $this->timezoneOffset = $dto->getTimezoneSec();
-            }
+//             if( !isset ($this->timezoneOffset) || $this->timezoneOffset === NULL)
+//             {
+//                 //retrieve time zone offset and store it, to avoid to call it for each link retrieval
+// //                 $dto = SMTSystemConfigurationDto::fetch( $this->getContext()->getDatabase() );
+// //                 $this->timezoneOffset = $dto->getTimezoneSec();
+
+//                 //retrieve time zone offset and store it, to avoid to call it for each link retrieval
+//                 //                 $dto = SMTSystemConfigurationDto::fetch( $this->getContext()->getDatabase() );
+//                 //                 $this->timezoneOffset = $dto->getTimezoneSec();
+//                 $this->timezoneOffset = SMTOtu::getTimeZoneOffsetSec($this->getContext());
+                
+//                 SMTLogger::getInstance()->trace( "retrieveLinkTest >> timezoneOffset: ".$this->timezoneOffset );
+//             }
+            
+//             $dateString = $this->sendReceive( SMTOtuApi::getLinkLastMonitoringDateCommand( $id ) );
+//             $linkDto->setLastMonitoringTimeStamp( SMTUtil::getTimestampUTC( $dateString, $this->getContext(), $this->timezoneOffset ) );
+            
             
             $dateString = $this->sendReceive( SMTOtuApi::getLinkLastMonitoringDateCommand( $id ) );
-            $linkDto->setLastMonitoringTimeStamp( SMTUtil::getTimestampUTC( $dateString, $this->getContext()->getDatabase(), $this->timezoneOffset ) );
+            $timestamp = ( isset( $dateString) && SMTUtil::isInt( $dateString) )? intval( $dateString ): NULL;
+            if ( $timestamp != NULL )
+            {
+                $linkDto->setLastMonitoringTimeStamp( $timestamp );
+            }
+            
             
             //retrieve both link availability and test availability, because if link is not available, it forbids the execution of a measurement on the link
 //             $linkDto->setMeasurementAllowed( $this->sendReceive( SMTOtuApi::getLinkAvailableCommand( $id ) ) == SMTOtuApi::RES_OK );
@@ -1149,15 +1166,22 @@ class SMTLinkTest extends SMTServiceHelper
         
         if ( $monitoringInfo )
         {
-            if( !isset ($this->timezoneOffset) || $this->timezoneOffset === NULL)
-            {
-                //retrieve time zone offset and store it, to avoid to call it for each link retrieval
-                $dto = SMTSystemConfigurationDto::fetch( $this->getContext()->getDatabase() );
-                $this->timezoneOffset = $dto->getTimezoneSec();
-            }
+//             if( !isset ($this->timezoneOffset) || $this->timezoneOffset === NULL)
+//             {
+//                 //retrieve time zone offset and store it, to avoid to call it for each link retrieval
+// //                 $dto = SMTSystemConfigurationDto::fetch( $this->getContext()->getDatabase() );
+// //                 $this->timezoneOffset = $dto->getTimezoneSec();
+//                 $this->timezoneOffset = SMTOtu::getTimeZoneOffsetSec($this->getContext());
+                
+//                 SMTLogger::getInstance()->trace( "retrieveLinkInfo >> timezoneOffset: ".$this->timezoneOffset );
+//             }
             
             $dateString = $this->sendReceive( SMTOtuApi::getLinkLastMonitoringDateCommand( $id ) );
-            $linkDto->setLastMonitoringTimeStamp( SMTUtil::getTimestampUTC( $dateString, $this->getContext()->getDatabase(), $this->timezoneOffset ) );
+            $timestamp = ( isset( $dateString) && SMTUtil::isInt( $dateString) )? intval( $dateString ): NULL;
+            if ( $timestamp != NULL )
+            {
+                $linkDto->setLastMonitoringTimeStamp( $timestamp );
+            }
         }         
         
         return $linkDto;        
@@ -1210,6 +1234,7 @@ class SMTLinkTest extends SMTServiceHelper
     	$peakNumber = 0;
     	try
     	{
+    	    $output_array = array();
     		$testDetailString = $socket->sendReceive( SMTOtuApi::getTestDescriptionCommand( $testId ), FALSE );
     		preg_match_all("/\"(?:[^\"]*?)\",|(?:[^,]*?),/", $testDetailString.',', $output_array);
     		
@@ -1225,9 +1250,9 @@ class SMTLinkTest extends SMTServiceHelper
     			$peakNumber= $thresholdCount - SMTThresholdBufferEncoderDecoder::TOPAZ_THRESHOLD_COUNT;
     		}
     	}
-    	catch( Exception $e )
+    	catch( \Exception $e )
     	{
-    		$this->getContext()->getLogger()->traceException($e);
+    	    SMTLogger::getInstance()->traceException($e);
     		$peakNumber = 0;
     	}
     	return $peakNumber;
@@ -1247,6 +1272,7 @@ class SMTLinkTest extends SMTServiceHelper
         
         try 
         {
+            $output_array = array();
             $testDetailString = $this->sendReceive( SMTOtuApi::getTestDescriptionCommand( $testId ), FALSE );
             
             preg_match_all("/\"(?:[^\"]*?)\",|(?:[^,]*?),/", $testDetailString.',', $output_array);
@@ -1439,7 +1465,7 @@ class SMTLinkTest extends SMTServiceHelper
      */
     function retrieveLinkInfoFromTest( $testId, $monitoringInfo = FALSE )
     {
-        $testDetail = NULL;
+//         $testDetail = NULL;
         try 
         {           
             //fetch the test
@@ -1835,7 +1861,14 @@ class SMTLinkTest extends SMTServiceHelper
             $name = trim( $linkInfoArray[self::LINK_UTF8_NAME_INDEX] );
             if ( strlen($name) <= 0 )
             {
-                $name = trim( $linkInfoArray[self::LINK_NAME_INDEX] );
+                if ( !SMTOtuMode::isSmartOtuFamily() )
+                {
+                    $name = utf8_encode(trim( $linkInfoArray[self::LINK_NAME_INDEX] ) );
+                }
+                else
+                {
+                    $name = trim( $linkInfoArray[self::LINK_NAME_INDEX] );
+                }
             }
             $linkDto->setName( $name );
             $linkDto->setModulePosition( trim( $linkInfoArray[self::LINK_MODULE_INDEX] ) );
@@ -2030,8 +2063,8 @@ class SMTLinkTest extends SMTServiceHelper
         
         $testDetail->setDeltaFirstLastMarkersThresholdsDb( $deltaFirstLastMarkerThreshold );
         
-        $hysteresisAttenuationAlarmThresholdListDto = $this->getHysteresisAttenuationAlarmThresholdList( $linkTestDto->getModuleRunningNumber() );
-        $testDetail->setHysteresisAttenuationThresholdsDbList($hysteresisAttenuationAlarmThresholdListDto);
+//         $hysteresisAttenuationAlarmThresholdListDto = $this->getHysteresisAttenuationAlarmThresholdList( $linkTestDto->getModuleRunningNumber() );
+//         $testDetail->setHysteresisAttenuationThresholdsDbList($hysteresisAttenuationAlarmThresholdListDto);
         
         
         $linkTestDto->setTestDetail($testDetail);
@@ -2056,6 +2089,7 @@ class SMTLinkTest extends SMTServiceHelper
      */
     private static function acquireTestSetupLock()
     {
+        $eWouldBlock = 0;
         $retries = 0;
         $max_retries = 10;
     
