@@ -68,6 +68,10 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
      */
     const MOD3 = "MOD3";
     
+    
+    const OSX_MODE_ALL_DISTRIBUTOR = 0;
+    const OSX_MODE_1_DISTRIBUTOR = 1;
+    
     /**
      * 
      * @var String
@@ -241,6 +245,40 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     	return strcasecmp( 'TRUE', $this->sendReceive( sprintf(SMTOtuApi::CMD_get_bigtopo, 0) ) ) == 0;
     }
     
+    /**
+     * Set internal switch PortsDistributorNumber (osx on last internal switch ports)
+     *
+     * @param string $bigTopology
+     * @param SMTOtuSocket $socket
+     */
+    static function setPortsDistributorNumber($PortsDistributorNumber, SMTOtuSocket $socket)
+    {
+        $socket->send( sprintf(SMTOtuApi::CMD_set_Nb_Port_Distributeur, $PortsDistributorNumber) );
+        
+        // force next detection
+        SMTOtuStatusCacheDto::setSwitchDetectedOnce(FALSE);
+    }
+    
+    /**
+     * Get internal switch PortsDistributorNumber (osx on last internal switch ports)
+     *
+     * @return int PortsDistributorNumber 
+     */
+    function getPortsDistributorNumber()
+    {
+        return intval($this->sendReceive( SMTOtuApi::CMD_get_Nb_Port_Distributeur ) );
+    }
+    
+    /**
+     * Has fixed Ports Distributor (new internal switch MOLEX on topologies C and D)
+     *
+     * @return int PortsDistributorNumber
+     */
+    function hasFixedPortsDistributor()
+    {
+        return strcasecmp( 'TRUE', $this->sendReceive( SMTOtuApi::CMD_Has_Fixed_Port_Distributeur) ) == 0;
+    }
+    
     /**
      * Full scan of osxs
      *
@@ -305,6 +343,7 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     function fullScan($scanOTAM)
     {
     	$osxList = new SMTOsxListDto();
+    	$switchMissing = FALSE;
     	
     	for ($i=1; $i<= SMTMacroSwitch::OSU_DISTRIBUTOR_INDEX; $i++)
     	{
@@ -317,7 +356,14 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     			}
     			else
     			{
-    				$osxDesc = $this->sendReceive( sprintf(SMTOtuApi::CMD_get_switch_jdsu_idn, $i) );
+    			    if ( $switchMissing )
+    			    {
+    				    $osxDesc = $this->sendReceive( sprintf(SMTOtuApi::CMD_get_switch_jdsu_idn_scan, $i) );
+    			    }
+    			    else 
+    			    {
+    			        $osxDesc = $this->sendReceive( sprintf(SMTOtuApi::CMD_get_switch_jdsu_idn, $i) );
+    			    }
     			}
     			$osxDesc= preg_replace('/[[:^print:]]/', '', $osxDesc);
     			if ( $osxDesc == self::INVALID_DESC_STRING)
@@ -326,6 +372,7 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     			}
     			if ( strlen($osxDesc) > 0)
     			{
+    			    $switchMissing = FALSE;
 	    			try 
 	    			{
 		    			$ports = $this->sendReceive( sprintf(SMTOtuApi::CMD_get_osu_ports, $i) );
@@ -349,6 +396,7 @@ class SMTSwitchManager extends SMTServiceHelper implements SMTISerializable
     		catch ( \Exception $e )
     		{
     			SMTLogger::getInstance()->traceException($e);
+    			$switchMissing = TRUE;
     		}
     	}
     	
