@@ -141,7 +141,6 @@ class SMTAPCMemoryUtil
      */
     static function fetchAllFromApcStore()
     {
-    	$success = FALSE;
     	$readTrialCount = 0;
     	$cache_user = array();
     	 
@@ -190,7 +189,7 @@ class SMTAPCMemoryUtil
     {
         $success = FALSE;
         $writeTrialCount = 0;
-        $writeId = rand(1, 10000);
+//         $writeId = rand(1, 10000);
 //         SMTLogger::getInstance()->trace("Start writing to APC store for :".$dto_key.$writeId);
 
         self::touchAPCMemory();
@@ -214,7 +213,7 @@ class SMTAPCMemoryUtil
                 
                 SMTLogger::getInstance()->trace("Write fake value to APC store for :".$dto_key, SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__);
             }
-            SMTLogger::getInstance()->trace("Couldn't write to APC store for :".$dto_key." and write Id:".$writeId, SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__);       
+            SMTLogger::getInstance()->trace("Couldn't write to APC store for :".$dto_key, SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__);       
         }
 //         SMTLogger::getInstance()->trace("End writing to APC store for :".$dto_key.$writeId );
         if ( !$success )
@@ -250,6 +249,7 @@ class SMTAPCMemoryUtil
     static function acquireLock()
     {
         $retries = 0;
+        $eWouldBlock = 0;
         
         // keep trying to get a lock as long as possible (max 1.5s)
         do {
