@@ -3,9 +3,10 @@ namespace app\util\upload;
 
 require_once('SMTUpload.php');
 
-use app\util\SMTLogger;
+use app\admin\SMTOtuType;
 use app\services\maintenance\SMTUploadStatusDto;
 use app\serviceshelper\maintenance\SMTUpgrade;
+use app\util\SMTLogger;
 use app\util\upload\SMTUploadStatus;
 
 /**
@@ -15,20 +16,37 @@ use app\util\upload\SMTUploadStatus;
 //2 hours script timeout ( OTU release at rate 500kb/s )
 set_time_limit(3600);
 
+function shutdown()
+{
+	//force the cleanup of the release running flag, in case of crash
+	SMTUploadStatus::setUploadRelaseRunning(FALSE);
+} 
+
 $upgradeDto = SMTUpgrade::getCurrentUpgrade();
 
 $noUploadRunning = SMTUploadStatus::checkNoUploadRunning();
 
-if ( !$upgradeDto->isUpgradeInProgressOnOtu() )
+if ( ($noUploadRunning == TRUE) && !$upgradeDto->isUpgradeInProgressOnOtu() )
 {
-    $uploadStatus = upload_file( SMTUpgrade::OTU_RELEASE_CURRENT_DIR );    
+	register_shutdown_function(__NAMESPACE__.'\\'.'shutdown');
+	SMTUploadStatus::setUploadRelaseRunning(TRUE);
+	
+	if ( SMTOtuType::isCOtu_EOTDRV2() )
+	{
+		$uploadStatus = upload_file( SMTUpgrade::OTU_RELEASE_CURRENT_DIR, 'check5kRelease');
+	}
+	else
+	{
+		$uploadStatus = upload_file( SMTUpgrade::OTU_RELEASE_CURRENT_DIR, 'check8kRelease');
+	}
+	SMTUploadStatus::setUploadRelaseRunning(FALSE);
 }
 else
 {
     $uploadStatus = new SMTUploadStatusDto();
     $uploadStatus->setProgress( SMTUploadStatusDto::NO_UPLOAD );
     if ( $noUploadRunning != TRUE )
-    {
+    {    	    	
         $uploadStatus->setUploadErrorStatus( SMTUploadStatusDto::UPLOAD_ALREADY_RUNNING );
         SMTLogger::getInstance()->trace("Upload already running...", SMTLogger::ERROR);
     }
@@ -37,6 +55,8 @@ else
     	$uploadStatus->setUploadErrorStatus( SMTUploadStatusDto::UPGRADE_ALREADY_RUNNING );
     	SMTLogger::getInstance()->trace("Upgrade already running...", SMTLogger::ERROR);
     }    
+    // add error code 401 in case of upload failure
+    @header('Cache-Control: no-cache, must-revalidate', true, 401 ); 
 }
 
 $response = buildJsonResponse( $uploadStatus );
