@@ -11,13 +11,7 @@ DPORT=$3
 SSHPORT=$4
 TMP_SSH_RESULT="/tmp/ssh.result"
 TMP_SSH_PID="/tmp/ssh.pid"
-SSH_STRONG="$(fw_printenv ssh_strong | cut -f2 -d= )"
-
-if [[ "$SSH_STRONG" == "true" ]] ; then
-    PRIVATE_KEY="/home/secuser/.ssh/otu_id_rsa_4096"
-else
-    PRIVATE_KEY="/home/secuser/.ssh/otu_id_rsa"
-fi
+PRIVATE_KEY="/home/secuser/.ssh/otu_id_rsa_4096"
 
 # ssh wait parameters (timeout is set to 15 seconds)
 COUNTER=0
@@ -42,7 +36,7 @@ rm -f $TMP_SSH_RESULT
 rm -f $TMP_SSH_PID
 
 # lancement et detachement de ssh en mode tunnel, timeout a 15 secondes
-ssh -i $PRIVATE_KEY -p $SSHPORT -o ConnectTimeout=$TESTTIMEOUT -L $LPORT:localhost:$DPORT secuser@$IP -N 2> $TMP_SSH_RESULT &
+ssh -i $PRIVATE_KEY -p $SSHPORT -o ConnectTimeout=$TESTTIMEOUT -o StrictHostKeyChecking=no -L $LPORT:localhost:$DPORT secuser@$IP -N 2> $TMP_SSH_RESULT &
 
 # get PID as command returned value, and save to file
 PID=$!
