@@ -90,4 +90,18 @@ else
         fi
 #    fi
 fi
+
+if [ `grep smartotu: /etc/group | wc -l` == 0 ];
+then
+   groupadd smartotu
+fi
+if [ `grep smartotu: /etc/shadow | wc -l` == 0 ];
+then
+   useradd -d /usr/share/apache2/htdocs -p \\\$1\\\$lyAU2uvD\\\$He7fcR4c8rwL6ImTs0sR3/ -r -s /bin/bash smartotu -g smartotu
+fi
+if [ `grep ntp: /etc/shadow | wc -l` == 0 ];
+then
+   useradd --system --home-dir /var/lib/ntp --no-create-home --shell /bin/false -g 993 ntp
+fi
+
 exit 0
