@@ -1,4 +1,4 @@
-import subprocess, os, time
+import subprocess, os, time, sys
 
 class Bootenv(object):
     def __init__(self):
@@ -26,7 +26,10 @@ class Bootenv(object):
         var = self.__dict__['__vars']
         var[k] = v
         subprocess.check_output(["fw_setenv", str(k), str(v)])
-        os.sync()
+        if sys.version_info[0] < 3:
+            os.system("sync")
+        else:
+            os.sync()
         time.sleep(1)
 
 bootenv = Bootenv()
