@@ -41,7 +41,7 @@ class MyFileObj(io.FileIO):
         percent = int(self.tell() * 100 / self.__fsize)
         if percent != self.lastpercent:
             if self.__cls is not None:
-                self.__cls.expose("Upgrade", 66, self.__rname, "Installation", percent)
+                self.__cls.expose("Upgrade", 50 + (percent * 0.4), self.__rname, "Installation", percent)
             self.lastpercent = percent
         return io.FileIO.read(self, size)
 
@@ -132,7 +132,8 @@ def start_upgrade_tar(xmlrelease, hook=None, options={}, smartmanager=None):
         percent = round(percent * 100, 2)
         if int(percent) != int(chunk_report.lastpercent):
             if smartmanager is not None:
-                smartmanager.expose("Upgrade", 33, name, "Download release", percent)
+                # Dowload during 0%~45% of total
+                smartmanager.expose("Upgrade", percent * 0.45, name, "Download release", percent)
             chunk_report.lastpercent = percent
 
     chunk_report.lastpercent = 1000
@@ -154,11 +155,11 @@ def start_upgrade_tar(xmlrelease, hook=None, options={}, smartmanager=None):
                 download_file(path + ".sig", "%s/%s.sig" % (lpath, tarf), options['proxy'], report_hook=chunk_report)
 
             if smartmanager is not None:
-                smartmanager.expose("Upgrade", 50, name, "Check integrity", 0)
+                smartmanager.expose("Upgrade", 46, name, "Check integrity", 0)
             print(
                 subprocess.check_output(["gpg", "--verify", "%s/%s.sig" % (lpath, tarf), "%s/%s" % (lpath, tarf)]))
             if smartmanager is not None:
-                smartmanager.expose("Upgrade", 50, name, "Check integrity", 100)
+                smartmanager.expose("Upgrade", 46, name, "Check integrity", 100)
     except subprocess.CalledProcessError as err:
         print("BAD SIGNATURE")
         if options['daemon']:
@@ -188,20 +189,20 @@ def start_upgrade_tar(xmlrelease, hook=None, options={}, smartmanager=None):
         if not os.path.exists("/mnt/fs"):
             os.makedirs("/mnt/fs")
         if smartmanager is not None:
-            smartmanager.expose("Upgrade", 60, name, "Prepare filesystem %s" % mmc_part_new, 10)
+            smartmanager.expose("Upgrade", 47, name, "Prepare filesystem %s" % mmc_part_new, 10)
         format_device(mmc_part_new)
         if smartmanager is not None:
-            smartmanager.expose("Upgrade", 60, name, "Prepare filesystem", 50)
+            smartmanager.expose("Upgrade", 48, name, "Prepare filesystem", 50)
         mount(options['flash_block_device'] + "p%s" % mmc_part_new, "/mnt/fs/", "ext4")
         if smartmanager is not None:
-            smartmanager.expose("Upgrade", 60, name, "Prepare filesystem", 60)
+            smartmanager.expose("Upgrade", 49, name, "Prepare filesystem", 60)
         if not os.path.exists("/mnt/fs/user/disk"):
             os.makedirs("/mnt/fs/user/disk")
         if smartmanager is not None:
-            smartmanager.expose("Upgrade", 60, name, "Prepare filesystem", 70)
+            smartmanager.expose("Upgrade", 50, name, "Prepare filesystem", 70)
         mount_bind("/user/disk", "/mnt/fs/user/disk")
         if smartmanager is not None:
-            smartmanager.expose("Upgrade", 60, name, "Prepare filesystem", 100)
+            smartmanager.expose("Upgrade", 50, name, "Prepare filesystem", 100)
             smartmanager.set_action("4: Install release")
 
         run_hook(hook, 'pre_tar_untar')
