@@ -2,14 +2,17 @@
 # coding: utf-8 
 # machine: eotdrv2
 
-ver='19-12-2019'
+ver='03-08-2021'
 repertoire=r"/sys/platform/"
 freqADC=160e6
 
 
 from importlib import reload
 from jdsu.evm import *          # dans /usr/lib/python3.5/jdsu/evm contient O()... , print_info....
-from jdsu.diag import *
+try:
+    from viavi.diag import *
+except:
+    from jdsu.diag import * #on devrait pouvoir le supprimer à terme...
 from time import time, sleep
 from jdsu.mts.uts_bdt import UtsBdt
 from math import log
@@ -17,7 +20,9 @@ import csv
 import traceback
 import collections
 from pathlib import Path
-from .eotdrv2_regs import *
+#~ from .eotdrv2_regs import *
+sys.path.append('/usr/share/pydiag/eotdrv2')#On utilise dorenavent le fichier de registres commun aux pydiag
+from eotdrv2_regs import *
 
 gain={  #gain hardware entre valeurs mesurees et entrees ADC
             "adc_vin":1/(1+4.64+10),   #R2+R4+R5=1K+4.64K+10K
@@ -285,11 +290,23 @@ class Otdr_Acq(object):
         return 0
 
     def enableAPD(self, enable):
+        with open("/sys/platform/powersupply/en_vcc_apd",'r') as f:   
+            old=f.read().strip().replace('0x','') #old vaut '0' ou '1'
+            
         if enable:
-            self.utsbdt.rw_register(UtsBdt.WRITE, REG_HARDWARE_CFG, 0x0000018, 0x10)
+            #~ self.utsbdt.rw_register(UtsBdt.WRITE, REG_HARDWARE_CFG, 0x0000018, 0x10)
+            with open("/sys/platform/powersupply/en_vcc_apd",'w') as f:    
+                f.write("1")
         else:
-            self.utsbdt.rw_register(UtsBdt.WRITE, REG_HARDWARE_CFG, 0x0000018, 0)
-        sleep(0.5)
+            #~ self.utsbdt.rw_register(UtsBdt.WRITE, REG_HARDWARE_CFG, 0x0000018, 0)
+            with open("/sys/platform/powersupply/en_vcc_apd",'w') as f:    
+                f.write("0")
+                
+        with open("/sys/platform/powersupply/en_vcc_apd",'r') as f:   
+            new=f.read().strip().replace('0x','') #new vaut '0' ou '1'
+        if int(old)!=int(new):
+            sleep(0.5)
+            
         return 0
 
     def loopOnGainAndRaman(self):
@@ -387,9 +404,6 @@ class Otdr_Acq(object):
     def write_regs(self,adr,mask,val):
         self.utsbdt.rw_register(UtsBdt.WRITE, adr, mask, val)
 
-
-
-
 class helice:
     def __init__(self):
         self.indice=0
@@ -533,22 +547,54 @@ def str2int(chaine):
         raw=int(chaine,base=0) #la valeur raw est en hexa
     return(raw)
     
-def setVAPD(volts,Nano=False):
+
+#APD
+Vmin=15.92; Vmax=97.81#selon FO
+#~ Vmin=15.92; Vmax=97.95#selon pdf schéma
+#~ Vmin=15.36; Vmax=100.72# selon derniers calculs
+
+def setVAPD(volts):
     otdr=Otdr_Acq()
     
-    if Nano:
-        Vmin=14.81
-        Vmax=57.2
-    else:
-        Vmin=15.358
-        Vmax=85.362
-    if volts>Vmin and volts<Vmax:
+    if volts<Vmin:
+        otdr.enableAPD(0)
+        print('APD is OFF')
+    elif volts<Vmax:
+        otdr.enableAPD(1)
         consigne=int(  (volts - Vmin) *65536/(Vmax-Vmin) )
         otdr.utsbdt.rw_register(UtsBdt.WRITE, REG_DAC_VCC_APD,     0xFFFFFFFF, consigne)
         print("%d=%Xh"%(consigne,int(consigne)))
     else:
         print("Out of range %.2fV - %.2fV"%(Vmin,Vmax))
-    
+
+def getVAPD(repeat=None):
+    '''retourne la valeur souhaitée (en Volts), pas celle obtenue'''
+    otdr=Otdr_Acq()
+    if repeat==None:
+        reg=int(otdr.utsbdt.rw_register(UtsBdt.READ, REG_DAC_VCC_APD,     0, 0))
+        val=(reg/65536)*(Vmax-Vmin)+Vmin
+        return(val)
+    else:
+        h=helice()
+        while(1):
+            print("%s"%h.run(),end='')
+            reg=int(otdr.utsbdt.rw_register(UtsBdt.READ, REG_DAC_VCC_APD,     0, 0))
+            val=(reg/65536)*(Vmax-Vmin)+Vmin     
+            print("%6.3f"%(val),end='\r',flush=True)
+            sleep(repeat)            
+
+def calcErrorDACAPD():
+    '''retourne DAC-ADC'''
+    val1=XADC('adc_vcc_apd',repeat=None)
+    diff1=getVAPD()-val1
+    print('DAC-ADC at %.1fV =%.1fV'%(val1,diff1))
+    for v in (45,40,35,30,25,20):
+        setVAPD(v)
+        sleep(1.5)
+        val2=XADC('adc_vcc_apd',repeat=None)
+        diff2=getVAPD()-val2
+        print('DAC-ADC at %.1fV =%.1fV'%(val2,diff2))
+
 def setVEE_LASER(volts):
     otdr=Otdr_Acq()
     consigne=int(float(volts)/10*65536)
@@ -569,7 +615,7 @@ def getDAC_LASER(surveillance=False,delay=0.5):
         h=helice()
         while(1):
             reg=otdr.utsbdt.rw_register(UtsBdt.READ, REG_DAC_CONSIGNE_LASER,     0, 0)
-            print("%sDAC_LAS = %d"%(h.run(),reg),end='\r')
+            print("%sDAC_LAS = %d    "%(h.run(),reg),end='\r')
             sleep(delay)
     else:
         reg=otdr.utsbdt.rw_register(UtsBdt.READ, REG_DAC_CONSIGNE_LASER,     0, 0)
@@ -1047,7 +1093,7 @@ def setLaserWidth(LW_ENT,LW_DEC):
     otdr=Otdr_Acq()
     otdr.utsbdt.rw_register(UtsBdt.WRITE, REG_LASER_WIDTH_ENT,  0xFFF, LW_ENT)
     otdr.utsbdt.rw_register(UtsBdt.WRITE, REG_LASER_WIDTH_DEC,  0xFFF, LW_DEC)
-    print('Pulse width = %.4fns'%getLaserWidth(False))
+    print('Pulse width = %.4fns'%getLaserWidth())
 
 def setAD9634_Register(address,value):
     open("/sys/platform/adcbdt/address",'w').write(str(address))
@@ -1170,8 +1216,8 @@ def getMeasIavg(otdr=None,debug=False,capacitor=0):
     rkm=otdr.utsbdt.rw_register(UtsBdt.READ, REG_PRIME_RECUR,  0, 0)*6.25 #ns
     raw=otdr.utsbdt.rw_register(UtsBdt.READ, REG_MEASI_AVG_RAW,  0, 0)
     dutyCycle=otdr.utsbdt.rw_register(UtsBdt.READ, REG_MEASI_AVG_DUTY,  0, 0)/2**26
-    dutyCycle=getLaserWidth(0)/rkm #autre methode
     try:
+        dutyCycle=getLaserWidth()/rkm #autre methode
         iavg=raw/R302/Gain_U69*(R324+R648)/R324/65536
         iavg-=capacitor*veelas/(rkm*1.e-9) #compensation des pertes par commutation dans capa trans pulseur
         ilas=iavg/dutyCycle
@@ -1221,6 +1267,31 @@ Output test mode\n\
     otdr.StartAndPoolAcq(False)
     otdr.DumpAcq(21)
 
+def getSourceStatus(otdr=None):
+    if otdr==None:
+        otdr=Otdr_Acq()
+    print("REG_LAS_SRC_EN         %08x" % otdr.utsbdt.rw_register(UtsBdt.READ, REG_LASER_SOURCE_ENABLE, 0, 0) )
+    print("REG_LAS_SRC_FREQ_MOD   %08x" % otdr.utsbdt.rw_register(UtsBdt.READ, REG_LASER_SOURCE_FREQ_MODULATION, 0, 0) )
+    print("REG_LAS_FREQ_FAST_MOD  %08x" % otdr.utsbdt.rw_register(UtsBdt.READ, REG_LASER_FREQ_FAST_MODULATION, 0, 0) )
+
+def enableSource(Laser=None):
+    if Laser==None:
+        print_info('Usage : enableSource(Laser)\navec Laser=001 ou 010 ou 100')
+        return
+    otdr=Otdr_Acq()
+    otdr.utsbdt.rw_register(UtsBdt.WRITE, REG_LASER_SOURCE_ENABLE, 0x0000FFFF, Laser)
+    getSourceStatus(otdr)
+    
+def setSourceFreqMod(freq):
+    otdr=Otdr_Acq()
+    otdr.utsbdt.rw_register(UtsBdt.WRITE, REG_LASER_SOURCE_FREQ_MODULATION, 0x0000FFFF, freq)
+    getSourceStatus(otdr)
+
+def setSourceFreqFastMod(freq):
+    otdr=Otdr_Acq()
+    otdr.utsbdt.rw_register(UtsBdt.WRITE, REG_LASER_FREQ_FAST_MODULATION, 0x0000FFFF, freq)
+    getSourceStatus(otdr)
+
 # *** Affichage versions ***
 print_info("pytools rev = %s"%ver)
 print_info("HW rev = %s"%getHWrev())
