@@ -330,12 +330,12 @@ def get_cdm2_test_plan(cdm_job):
     except KeyError:
         return test_plan
     for test in tests:
-        planned_test = {'test_type' : test['type'],
+        planned_test = {'test_type' : test.get('type'),
                         'status' : get_status(test),
-                        'test_label' : test['label']
+                        'test_label' : test.get('label')
                         }
 
-        log.debug('## Planned test type = %s', planned_test['test_type'] )
+        log.debug('## Planned test type = %s', planned_test.get('test_type') )
 
         refinfolist = []
         stinfolist = []
@@ -361,7 +361,7 @@ def get_cdm2_test_plan(cdm_job):
                         if planned_test['test_type'] != 'OTDR':
                             # Bodge (OTDR not storing this info yet - breaks 'matches' test)
                             # Exclude OTDR subTypeInfo for now
-                            allSubTypeInfo = get_genfield_value( test_loc['attributes'], attrib_key )
+                            allSubTypeInfo = get_genfield_value( test_loc.get('attributes'), attrib_key )
                             log.debug('##   subTypeInfo attribute= %s', allSubTypeInfo )
                             for stKey in allSubTypeInfo:
                                 stinfo = {}
@@ -380,14 +380,21 @@ def get_cdm2_test_plan(cdm_job):
         planned_test['procedures'] = test.get('procedures', "")
 
         planned_test['workflow_id'] = test.get('workflow_id', 0)
-        log.debug('##   test workflowId= %d', planned_test['workflow_id'] )
+        log.debug('##   test workflowId= %d', planned_test.get('workflow_id') )
+
+        planned_test['config'] = test.get('configuration', {})
+        log.debug('##   test.configuration: %s', test.get('configuration'))
+        log.debug('##   config: %s', planned_test.get('config'))
+        
+        #if 'test_type' not part of the 'config' object add it in
+        if 'test_type' not in planned_test['config']:
+            planned_test['config']['test_type'] = test.get('type')
+            log.debug('##   add in job mgr testType: %s', planned_test['config']['test_type'] )
+
+        if 'test_type' in planned_test['config'] and planned_test['config']['test_type'] == 'fromCdm':
+            planned_test['config']['test_type'] = test.get('type')
+            log.debug('##   changed fromCdm to CDM testType: %s', planned_test['config']['test_type'])
 
-        planned_test['config'] = test.get('configuration')
-        log.debug('##   config: %s \n', planned_test['config'])
-        #if 'test_type' not in planned_test.keys():
-        if not 'test_type' in planned_test['config']:
-            log.debug('##   add in job mgr testType: ')
-            planned_test['config']['test_type'] = test['type']
 
         planned_test['test_data'] = []
         
