@@ -18,6 +18,8 @@ PRODUCT_STR_TO_MODULE_STR = {
     'fiberMts': 'products.fiber_base', # RestAPI baseline for MTS4kv2, MTS2kv2 and SmartOTDR
     'fiberJobMgr': 'products.fiber_mts_jobmgr', # fiber_base with JobMgr support on top
     'ONA-800': 'products.ona_800',
+    'ONA-1000': 'products.ona_800',
+    'CA5000': 'products.ona_ca5g',
     'off-target': 'products.product_specific_base'
 }
 
