@@ -8,7 +8,7 @@ USC_SERVICE = "com.jdsu.usc"
 USC_PATH = "/Usc"
 
 CDM_DOWNSTREAM_FILEPATH = '/tmp/cdm'
-
+CDM_DOWNSTREAM_TEMPLATES_PATH = '/tmp/workflow' #  **already provided to USC by ISU but also needed here**
 
 def register_cdm_filepath():
     """
@@ -20,3 +20,7 @@ def register_cdm_filepath():
         if not os.path.exists(CDM_DOWNSTREAM_FILEPATH):
             os.makedirs(CDM_DOWNSTREAM_FILEPATH)
         proxy_object.Register_Root_Path(CDM_DOWNSTREAM_FILEPATH)
+
+        if not os.path.exists(CDM_DOWNSTREAM_TEMPLATES_PATH):
+            os.makedirs(CDM_DOWNSTREAM_TEMPLATES_PATH)
+        proxy_object.Register_Root_Path(CDM_DOWNSTREAM_TEMPLATES_PATH)
