@@ -1,5 +1,5 @@
-from jdsu.evm import *
-from jdsu.diag import *
+from viavi.evm import *
+from viavi.diag import *
 import jdsu.mts as mts
 import hashlib
 import os
