@@ -1,5 +1,5 @@
-from jdsu.evm import *
-from jdsu.diag import *  # needed to define RESOURCE name and sysfs_* functions (see /usr/lib/python3.5/jdsu/diag/)
+from viavi.evm import *
+from viavi.diag import *  # needed to define RESOURCE name and sysfs_* functions (see /usr/lib/python3.5/jdsu/diag/)
 # from time import time, localtime, sleep            # needed for sleep()
 from time import sleep
 import time
